import { isOn, set } from 'feature-toggle-service';
import { Component, Input, ElementRef, NgZone, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleComponent {
    /**
     * @param {?} _el
     * @param {?} _zone
     */
    constructor(_el, _zone) {
        this._el = _el;
        this._zone = _zone;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureName) {
            throw new Error('Attribute `featureName` should not be null or empty');
        }
        this.shouldRender();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this._zone.runOutsideAngular(() => {
            this.shouldRender();
        });
    }
    /**
     * @return {?}
     */
    shouldRender() {
        /** @type {?} */
        const showWhenDisabled = this._el.nativeElement.getAttribute('showWhenDisabled') !== null;
        /** @type {?} */
        const toggleState = isOn(this.featureName);
        return toggleState === !showWhenDisabled;
    }
}
FeatureToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle',
                template: '<ng-content *ngIf="shouldRender()"></ng-content>'
            }] }
];
/** @nocollapse */
FeatureToggleComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: NgZone }
];
FeatureToggleComponent.propDecorators = {
    featureName: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleProviderComponent {
    constructor() {
        this.features = {};
        this.currentConfig = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `features` should not be null or empty');
        }
        this.setFeatureToggles();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this.setFeatureToggles();
    }
    /**
     * @private
     * @return {?}
     */
    setFeatureToggles() {
        if (this.currentConfig !== this.features) {
            this.currentConfig = this.features;
            set(this.features);
        }
    }
}
FeatureToggleProviderComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle-provider',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
FeatureToggleProviderComponent.propDecorators = {
    features: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleModule {
}
FeatureToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FeatureToggleProviderComponent, FeatureToggleComponent],
                exports: [FeatureToggleProviderComponent, FeatureToggleComponent],
                imports: [CommonModule],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FeatureToggleComponent, FeatureToggleProviderComponent, FeatureToggleModule };

//# sourceMappingURL=ngx-feature-toggle.js.map